*****************
How to contribute
*****************

We welcome contributions from anyone via pull requests on `GitHub
<https://github.com/nanophyto/abil>`_. If you don't feel comfortable modifying or
adding functionality, we also welcome feature requests and bug reports as
`GitHub issues <https://github.com/nanophyto/abil/issues>`_.


Running the unit tests
----------------------
To run a unit test, make sure you are under the project root:

.. code-block:: sh

   python -m unittest tests/test.py